================
Django Nomadblog
================

Overview
========

This is a basic Django application implementing the simplest form of a
blogging system. It's able to handle multible blogs and users.
It has been written with an eye put on keeping modularity and flexibility as
much as possible, so you won't find lots of goodies in the code (tagging,
related posts, blogroll), but just a couple of features to help you start
hacking it to your needs.

Read the latest documentation on the fine `Read the docs`_ project for install,
configuration and customization instructions.

.. _`Read the docs`: http://readthedocs.org/docs/django-nomadblog/en/latest/
